@@ -3,9 +3,9 @@ BEGIN {
   $HTTP::Headers::ActionPack::Core::BaseHeaderWithParams::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $HTTP::Headers::ActionPack::Core::BaseHeaderWithParams::VERSION = '0.05';
+  $HTTP::Headers::ActionPack::Core::BaseHeaderWithParams::VERSION = '0.06';
 }
-# ABSTRACT: A Base header type with params
+# ABSTRACT: A Base header type with parameters
 
 use strict;
 use warnings;
@@ -69,11 +69,11 @@ __END__
 
 =head1 NAME
 
-HTTP::Headers::ActionPack::Core::BaseHeaderWithParams - A Base header type with params
+HTTP::Headers::ActionPack::Core::BaseHeaderWithParams - A Base header type with parameters
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -82,7 +82,7 @@ version 0.05
 =head1 DESCRIPTION
 
 This is a base class for header values which contain
-a parameter list. There is no real user servicable parts
+a parameter list. There are no real user serviceable parts
 in here.
 
 =head1 METHODS
@@ -91,7 +91,7 @@ in here.
 
 =item C<params>
 
-Accessor for the unordered hash-ref of params.
+Accessor for the unordered hash-ref of parameters.
 
 =item C<add_param( $key, $value )>
 
@@ -104,7 +104,7 @@ Remove a parameter from the link.
 
 =item C<params_are_empty>
 
-Returns false if there are no parameters on the invovant.
+Returns false if there are no parameters on the invocant.
 
 =back
 
@@ -112,6 +112,32 @@ Returns false if there are no parameters on the invovant.
 
 Stevan Little <stevan.little@iinteractive.com>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Andrew Nelson <anelson@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Infinity Interactive, Inc..
