@@ -3,7 +3,7 @@ BEGIN {
   $HTTP::Headers::ActionPack::WWWAuthenticate::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $HTTP::Headers::ActionPack::WWWAuthenticate::VERSION = '0.05';
+  $HTTP::Headers::ActionPack::WWWAuthenticate::VERSION = '0.06';
 }
 # ABSTRACT: The WWW-Authenticate Header
 
@@ -26,7 +26,7 @@ HTTP::Headers::ActionPack::WWWAuthenticate - The WWW-Authenticate Header
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -86,6 +86,32 @@ it is based on the L<HTTP::Headers::ActionPack::Core::BaseAuthHeader> class.
 
 Stevan Little <stevan.little@iinteractive.com>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Andrew Nelson <anelson@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Infinity Interactive, Inc..
